@@ -1,9 +1,10 @@
 // SPDX-FileCopyrightText: 2022 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
-#include "profileeditor.h"
+#include "account/profileeditor.h"
 
-#include "abstractaccount.h"
+#include "account/abstractaccount.h"
+#include "utils/texthandler.h"
 
 #include <KLocalizedString>
 
@@ -40,7 +41,11 @@ QString ProfileEditorBackend::displayName() const
 
 QString ProfileEditorBackend::displayNameHtml() const
 {
-    return CustomEmoji::replaceCustomEmojis(m_account->customEmojis(), m_displayName);
+    if (m_account != nullptr) {
+        return TextHandler::replaceCustomEmojis(m_account->customEmojis(), m_displayName);
+    } else {
+        return m_displayName;
+    }
 }
 
 void ProfileEditorBackend::setDisplayName(const QString &displayName)
