@@ -1,7 +1,7 @@
 // SPDX-FileCopyrightText: 2021 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: GPL-2.0-or-later
 
-#include "mockaccount.h"
+#include "autotests/mockaccount.h"
 #include "account/notificationhandler.h"
 #include "autotests/helperreply.h"
 
@@ -143,11 +143,6 @@ void MockAccount::validateToken(bool newAccount)
     Q_UNUSED(newAccount)
 }
 
-bool MockAccount::hasFollowRequests() const
-{
-    return false;
-}
-
 void MockAccount::checkForFollowRequests()
 {
 }
@@ -213,6 +208,18 @@ void MockAccount::pollNotification()
     readNotificationFromFile("notification_poll.json"_L1);
 }
 
+void MockAccount::increaseFollowRequests()
+{
+    m_followRequestCount++;
+    Q_EMIT followRequestCountChanged();
+}
+
+void MockAccount::decreaseFollowRequests()
+{
+    m_followRequestCount--;
+    Q_EMIT followRequestCountChanged();
+}
+
 void MockAccount::readNotificationFromFile(QLatin1String filename)
 {
     QFile statusExampleApi;
